@@ -4,7 +4,7 @@ use Moose::Role;
 use Text::SimpleTable;
 use JSON ();
 
-our $VERSION   = '0.02';
+our $VERSION   = '0.03';
 our $AUTHORITY = 'cpan:STEVAN';
 
 around 'build_handler' => sub {
@@ -13,29 +13,30 @@ around 'build_handler' => sub {
     my $handler = $self->$next(@_);
     return sub {
         my $request = shift;
-    
+
         my $t = Text::SimpleTable->new(15, 55);
-        $t->row('Request', $request->request_uri);        
-        $t->row('Method',  $request->method);                
-        
-        my $t2 = Text::SimpleTable->new([ 15, 'Parameter' ], [ 55, 'Value' ]);        
-        $t2->row($_, $request->param($_)) for sort $request->param;        
-        
+        $t->row('Request', $request->uri);
+        $t->row('Method',  $request->method);
+
+        my $params = $request->uri->query_form_hash;
+        my $t2 = Text::SimpleTable->new([ 15, 'Parameter' ], [ 55, 'Value' ]);
+        $t2->row($_, $params->{$_}) for sort keys %$params;
+
         warn $t->draw, "\n", $t2->draw, "\n";
-        
+
         my $response = $handler->($request);
-        
-        my $t3 = Text::SimpleTable->new(15, 55);        
+
+        my $t3 = Text::SimpleTable->new(15, 55);
         $t3->row(
             'Response' => JSON->new->pretty(1)->encode(
                 JSON->new->decode(
-                    $response->body
+                    $response->content
                 )
             )
         );
-        
+
         warn $t3->draw, "\n";
-        
+
         return $response;
     }
 };
@@ -61,13 +62,13 @@ JSORB::Server::Traits::WithDebug - A debugging trait for JSORB::Server::Simple
 
 =head1 DESCRIPTION
 
-This is a trait meant to be used with L<JSORB::Server::Simple> 
+This is a trait meant to be used with L<JSORB::Server::Simple>
 to aid in debugging. It basically prints out nicely formatted
 ASCII tables to STDERR.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no 
+All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
